from setuptools import setup, find_packages

setup(
    name='KIMOJI_ATM',
    version='0.0.2',
    packages=find_packages(),
    install_requires=[
        'beautifulsoup4==4.12.2',
        'bencodepy==0.9.5',
        'bs4==0.0.1',
        'certifi==2023.7.22',
        'charset-normalizer==3.3.2',
        'cloudscraper==1.2.71',
        'docutils==0.20.1',
        'idna==3.4',
        'importlib-metadata==6.8.0',
        'jaraco.classes==3.3.0',
        'keyring==24.3.0',
        'markdown-it-py==3.0.0',
        'mdurl==0.1.2',
        'MediaInfo==0.0.9',
        'more-itertools==10.1.0',
        'nh3==0.2.14',
        'packaging==23.2',
        'pkginfo==1.9.6',
        'Pygments==2.17.1',
        'pymediainfo==6.1.0',
        'pyparsing==3.1.1',
        'PyYAML==6.0.1',
        'qbittorrent-api==2023.11.55',
        'readme-renderer==42.0',
        'requests==2.31.0',
        'requests-toolbelt==1.0.0',
        'rfc3986==2.0.0',
        'rich==13.7.0',
        'soupsieve==2.5',
        'tmdbv3api==1.9.0',
        'twine==4.0.2',
        'urllib3==2.1.0',
        'zipp==3.17.0'
    ],
    classifiers=[
        # 分类信息，用于帮助用户找到你的包
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
    python_requires='>=3.8',  # 指定支持的Python版本
)

